# Changelog

- 0.0.7
  - fix esbuild incompatibility in windows
- 0.0.6
  - fix wls incompatibility
- 0.0.5
  - adding draft models to down
  - removing conversion in js and ts entry code
  - adding --config to tko
  - changing @ for _ in downloaded problems folder name
